<?php
namespace MaxwheelsSpace;
/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.2.0
 */
class Plugin {
	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
	
	public function enqueue_styles() {
		wp_enqueue_style( "maxwheels-elementor-css", plugins_url('maxwheels-elementor/assets/css/elementor.css'));
	}

	/**
	 * Include Widgets files
	 *
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/hero-slider.php' );
		require_once( __DIR__ . '/widgets/hero-slider2.php' );
		require_once( __DIR__ . '/widgets/hero-main.php' );
		require_once( __DIR__ . '/widgets/hero-classic.php' );
		require_once( __DIR__ . '/widgets/hero-1.php' );
		require_once( __DIR__ . '/widgets/hero-2.php' );
		require_once( __DIR__ . '/widgets/hero-3.php' );
		require_once( __DIR__ . '/widgets/hero-4.php' );
		require_once( __DIR__ . '/widgets/hero-5.php' );
		require_once( __DIR__ . '/widgets/hero-9.php' );
		require_once( __DIR__ . '/widgets/hero-mod.php' );
		require_once( __DIR__ . '/widgets/blocks.php' );
		require_once( __DIR__ . '/widgets/all-listings.php' );
		require_once( __DIR__ . '/widgets/all-listings-lists.php' );
		require_once( __DIR__ . '/widgets/all-agencies.php' );
		require_once( __DIR__ . '/widgets/categories-simple.php' );
		require_once( __DIR__ . '/widgets/categories-simple-with-slider.php' );
		require_once( __DIR__ . '/widgets/all-categories.php' );
		require_once( __DIR__ . '/widgets/all-types.php' );
		require_once( __DIR__ . '/widgets/all-types-2.php' );
		require_once( __DIR__ . '/widgets/body-type-classic.php' );
		require_once( __DIR__ . '/widgets/body-type-slider.php' );
		require_once( __DIR__ . '/widgets/all-types-3.php' );
		require_once( __DIR__ . '/widgets/makes.php' );
		require_once( __DIR__ . '/widgets/makes2.php' );
		require_once( __DIR__ . '/widgets/makes3.php' );
		require_once( __DIR__ . '/widgets/makes4.php' );
		require_once( __DIR__ . '/widgets/blogs.php' );
		require_once( __DIR__ . '/widgets/testimonials2.php' );
		require_once( __DIR__ . '/widgets/testimonials3.php' );
		require_once( __DIR__ . '/widgets/testimonials4.php' );
		require_once( __DIR__ . '/widgets/partners.php' );
		require_once( __DIR__ . '/widgets/funfacts-1.php' );
		require_once( __DIR__ . '/widgets/funfacts-2.php' );
		require_once( __DIR__ . '/widgets/how-it-works.php' );
		require_once( __DIR__ . '/widgets/how-it-works2.php' );
		require_once( __DIR__ . '/widgets/our-services.php' );
		require_once( __DIR__ . '/widgets/our-services-1.php' );
		require_once( __DIR__ . '/widgets/our-services-2.php' );
		require_once( __DIR__ . '/widgets/about-us.php' );
		require_once( __DIR__ . '/widgets/about-us1.php' );
		require_once( __DIR__ . '/widgets/locations.php' );
		require_once( __DIR__ . '/widgets/locations2.php' );
		require_once( __DIR__ . '/widgets/our-app.php' );
		require_once( __DIR__ . '/widgets/our-app2.php' );
		require_once( __DIR__ . '/widgets/call-action-1.php' );
		require_once( __DIR__ . '/widgets/call-action-2.php' );
		require_once( __DIR__ . '/widgets/call-action-3.php' );
        require_once( __DIR__ . '/widgets/call-action-4.php' );
		require_once( __DIR__ . '/widgets/call-action-5.php' );
		require_once( __DIR__ . '/widgets/call-action-6.php' );
		require_once( __DIR__ . '/widgets/search-builder.php' );
		require_once( __DIR__ . '/widgets/search-builder-2.php' );
		require_once( __DIR__ . '/widgets/contactus.php' );
        require_once( __DIR__ . '/widgets/packages.php' );
        require_once( __DIR__ . '/widgets/packages-classic.php' );
		require_once( __DIR__ . '/widgets/dealers-slider.php' );
		require_once( __DIR__ . '/widgets/all-products.php' );
		require_once( __DIR__ . '/widgets/shop-support.php' );
		require_once( __DIR__ . '/widgets/shop-categories.php' );
	}
	
	//Ad Shortcode Category
	public function add_elementor_widget_categories($category_manager)
	{
            $category_manager->add_category(
				'sonutheme',
				[
					'title' => __( 'Maxwheels Widgets', 'maxwheels-elementor' ),
					'icon' => 'fa fa-home',
				]
            );
    }
	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Slider());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Slider2());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Main());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Classic());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_One());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Two());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Three());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Four());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Five());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Hero_Nine());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\HeroMod());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Block());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\All_Listings());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\All_Listings_List());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\All_Agencies());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\AllCategories());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CategoriesSimple());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CategoriesSimpleSlider());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Types());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\AllTypes());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BodyTypeClassic());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BodyTypeSlider());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\AllTypes3());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Blogs());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Makes());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Makes2());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Makes3());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Makes4());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Testimonials2());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Testimonials3());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Testimonials4());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Partners());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\FunFacts1());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\FunFacts2());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\HowItWorks());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\How_it_Works());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\OurServices());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\OurServices1());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\OurServices2());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\About_Us());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\About_Us1());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Locations());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Locations2());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\OurApps());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\OurApps2());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CallAction_One());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CallAction_Two());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CallAction_Three());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CallAction_Four());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CallAction_Five());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CallAction_Six());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\SearchBuilder());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\SearchBuilder_Two());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\ContactUs());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\All_Dealers());
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\ShopSupport());
        if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))))
        {
            \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Packages());
            \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\PackagesClassic());
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\All_Products());
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\ShopCats());
        }
	}
	public function __construct() {
		add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'enqueue_styles' ] );
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
		add_action( 'elementor/elements/categories_registered',  [ $this, 'add_elementor_widget_categories' ]  );
	}
}
Plugin::instance();