<?php
namespace MaxwheelsSpace\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class About_Us extends Widget_Base {
	
	public function get_name() {
		return 'about-us-one';
	}
	
	public function get_title() {
		return __( 'About Us', 'maxwheels-elementor' );
	}
	
	public function get_icon() {
		return 'maxwheels-icon';
	}

	public function get_categories() {
		return [ 'sonutheme' ];
	}
	
	public function get_script_depends() {
		return [ '' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	 
	protected function register_controls() {
		
		$this->start_controls_section(
			'section_query',
			[
				'label' => esc_html__( 'About Us Content', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'tagline', [
				'label' => __( 'Tagline', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'heading_text',
			[
				'label' => __( 'Main Heading', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'title' => __( 'To highligt heading use color tag eg: {color} Awesome </color>', 'maxwheels-elementor' ),
				'rows' => 3,
				'placeholder' => __( 'To highligt heading use color tag eg: {color} Awesome </color>', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'phone', [
				'label' => __( 'Phone No', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'default' => __( '012-345-6789', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'email', [
				'label' => __( 'Email', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'default' => __( 'your@email.com', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'main_btn_title',
			[
				'label' => __( 'Main Button Title', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __( 'Type your title here', 'maxwheels-elementor' ),
				'label_block' => true
			]
		);
		
		$this->add_control(
			'main_btn_link',
			[
				'label' => __( 'Main Button Link', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'maxwheels-elementor' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'content',
			[
				'label' => __( 'Content', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => __( 'Your Content Here', 'maxwheels-elementor' ),
			]
		);
        $this->add_control(
            'image_signature',
            [
                'label' => __( 'Upload Your signature Image', 'maxwheels-elementor' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_control(
            'image_profiler',
            [
                'label' => __( 'Upload Your Profiler Image', 'maxwheels-elementor' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_control(
            'profiler_name',
            [
                'label' => __( 'Write Your Profiler Name', 'maxwheels-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'Type your Name here', 'maxwheels-elementor' ),
                'label_block' => true
            ]
        );
        $this->add_control(
            'profiler_desig',
            [
                'label' => __( 'Write Your Profiler Designation', 'maxwheels-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'Type your Designation here', 'maxwheels-elementor' ),
                'label_block' => true
            ]
        );
		$this->end_controls_section();
		
		$this->start_controls_section(
			'video_query',
			[
				'label' => esc_html__( 'Video Section', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'videolink', [
				'label' => __( 'Youtube Video Link', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		$this->add_control(
			'image_first',
			[
				'label' => __( 'First Image', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'image_second',
			[
				'label' => __( 'Second Image', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->end_controls_section();
	}
	
		protected function render() {
		// get our input from the widget settings.
		$settings = $this->get_settings_for_display();
		$params['tagline'] = $settings['tagline'];
		$params['main_heading'] = $settings['heading_text'];
		$params['content'] = $settings['content'];
        $params['image_signature'] = $settings['image_signature']['url'] ? $settings['image_signature']['url'] : '';
        $params['image_profiler'] = $settings['image_profiler']['url'] ? $settings['image_profiler']['url'] : '';
        $params['profiler_name'] = $settings['profiler_name'] ? $settings['profiler_name'] : '';
        $params['profiler_desig'] = $settings['profiler_desig'] ? $settings['profiler_desig'] : '';
        $params['phone'] = $settings['phone'];
		$params['email'] = $settings['email'];
		//video
		$params['videolink'] = $settings['videolink'] ? $settings['videolink'] : '';
		$params['first_image'] = $settings['image_first']['url'] ? $settings['image_first']['url'] : '';
		$params['second_image'] = $settings['image_second']['url'] ? $settings['image_second']['url'] : '';
			echo Maxwheels_elementor_about_us($params);
		}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
}