<?php
namespace MaxwheelsSpace\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class All_Listings_List extends Widget_Base {
	
	public function get_name() {
		return 'all-listings-list';
	}
	
	public function get_title() {
		return __( 'All Listings Lists', 'maxwheels-elementor' );
	}
	
	public function get_icon() {
		return 'maxwheels-icon';
	}

	public function get_categories() {
		return [ 'sonutheme' ];
	}
	
	public function get_script_depends() {
		return [ '' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	public function get_customparant_terms($taxonomy)
	{
		$type = array();
		$terms = get_terms( array( 'taxonomy' => $taxonomy, 'parent' => 0, 'hide_empty' => 0 ));
		$type = ['all' => 'All'];
		if ( ! empty( $terms ) && ! is_wp_error( $terms ) )
		{
			foreach ( $terms as $term ) {
				$type[$term->term_id] = $term->name . ' (' . $term->count . ')';				
			}
		}
		return $type;
	}
	 
	 
	protected function register_controls() {
		$type = array();
		
		$all_locations = array();
		Maxwheels_framework_terms_array('mw-location' , $all_locations);
	
		$this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Listing Filters', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
            'show_loadmore',
            [
                'label' => esc_html__( 'Hide Load More Button', 'maxwheels-elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'maxwheels-elementor' ),
                'label_off' => esc_html__( 'No', 'maxwheels-elementor' ),
                'return_value' => 'none',
                'default' => 'no',
                'selectors' => [
                    '{{WRAPPER}} .is-show-load-more' => 'display: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
			'listing_type',
			[
				'label' => __( 'Listing Type', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all'  => __( 'All', 'maxwheels-elementor' ),
					'simple' => __( 'Simple', 'maxwheels-elementor' ),
					'featured' => __( 'Featured', 'maxwheels-elementor' ),
				],
			]
		);
		
		$this->add_control(
			'listing_order',
			[
				'label' => __( 'OrderBy', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'desc'  => __( 'Latest', 'maxwheels-elementor' ),
					'asc' => __( 'Oldest', 'maxwheels-elementor' ),
					'rand' => __( 'Random', 'maxwheels-elementor' ),
				],
			]
		);
		
		$this->add_control(
			'listing_layout',
			[
				'label' => __( 'Layout Type', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'list1',
				'options' => [
					'list1'  => __( 'List Style 1', 'maxwheels-elementor' ),
					'list2' => __( 'List Style 2', 'maxwheels-elementor' ),
					'list3' => __( 'List Style 3', 'maxwheels-elementor' ),
					'list4' => __( 'List Style 4', 'maxwheels-elementor' ),
					'list5' => __( 'List Style 5', 'maxwheels-elementor' ),
				],
			]
		);
		
		$this->add_control(
			'listing_status',
			[
				'label' => __( 'Body Type', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'all',
				'options' =>  $this->get_customparant_terms('mw-bodytype')
			]
		);
		
	
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Number of Listings', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 60,
				'step' => 1,
				'default' => 8,
			]
		);
		
		$this->add_control(
			'location',
			[
				'label' => __( 'Select Locations', 'maxwheels-elementor' ),
				'label_block'=>true,
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => false,
				'options' => $all_locations,
				'description' => __( 'Show properties for a particular location', 'maxwheels-elementor' ),
			]
		);	
		
		$this->add_control(
			'categories',
			[
				'label' => __( 'Select Type', 'maxwheels-elementor' ),
				'label_block'=>true,
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $this->get_customparant_terms('mw-category'),
				'default' => ['all'],
			]
		);	
		$this->end_controls_section();	
	}
	
		protected function render() {
		// get our input from the widget settings.
		$settings = $this->get_settings_for_display();
		$params['listing_type'] = $settings['listing_type'] ? $settings['listing_type'] : 'all';
		$params['orderby'] = $settings['listing_order'] ? $settings['listing_order'] : 'desc';
		$params['layout'] = $settings['listing_layout'] ? $settings['listing_layout'] : 'type5';
		$params['listing_status'] = $settings['listing_status'] ? $settings['listing_status'] : 'all';
		$params['location_id'] = $settings['location'] ? $settings['location'] : '';
		$params['no_of_post'] = $settings['posts_per_page'] ? (int)$settings['posts_per_page'] : 6;
		$params['listing_column'] = '';
		$params['categories'] = $settings['categories'] ? $settings['categories'] : 'all';
		
			echo maxwheels_elementor_all_listings($params,'no');
		}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
}