<?php
namespace MaxwheelsSpace\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class All_Products extends Widget_Base {
	
	public function get_name() {
		return 'all-woo-products';
	}
	
	public function get_title() {
		return __( 'All Products', 'maxwheels-elementor' );
	}
	
	public function get_icon() {
		return 'maxwheels-icon';
	}

	public function get_categories() {
		return [ 'sonutheme' ];
	}
	
	public function get_script_depends() {
		return [ '' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	public function get_customparant_terms($taxonomy)
	{
		$type = array();
		$terms = get_terms( array( 'taxonomy' => $taxonomy, 'parent' => 0, 'hide_empty' => 0 ));
		$type = ['all' => 'All'];
		if ( ! empty( $terms ) && ! is_wp_error( $terms ) )
		{
			foreach ( $terms as $term ) {
				$type[$term->term_id] = $term->name . ' (' . $term->count . ')';				
			}
		}
		return $type;
	}
	 
	 
	protected function register_controls() {
		$type = array();
		
		$all_locations = array();
		Maxwheels_framework_terms_array('mw-location' , $all_locations);
	
		$this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Products Filters', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'listing_type',
			[
				'label' => __( 'Product Type', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all'  => __( 'All', 'maxwheels-elementor' ),
					'simple' => __( 'Simple', 'maxwheels-elementor' ),
					'featured' => __( 'Featured', 'maxwheels-elementor' ),
					'on_sale' => __( 'On Sale', 'maxwheels-elementor' ),
				],
			]
		);
		
		$this->add_control(
			'listing_order',
			[
				'label' => __( 'OrderBy', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'desc'  => __( 'Latest', 'maxwheels-elementor' ),
					'asc' => __( 'Oldest', 'maxwheels-elementor' ),
					'rand' => __( 'Random', 'maxwheels-elementor' ),
				],
			]
		);
		$this->add_control(
			'listing_column',
			[
				'label' => __( 'Column Size', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '4',
				'description' => __( 'Use 2 columns only when using sidebar.', 'maxwheels-elementor' ),
				'options' => [
					'4'  => __( '4 Columns', 'maxwheels-elementor' ),
					'3'  => __( '3 Columns', 'maxwheels-elementor' ),
					'2' => __( '2 Columns', 'maxwheels-elementor' ),
					'12' => __( '1 Columns', 'maxwheels-elementor' ),
				],
			]
		);
		
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Number of Products', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 60,
				'step' => 1,
				'default' => 8,
			]
		);
		$this->add_control(
			'categories',
			[
				'label' => __( 'Select Category', 'maxwheels-elementor' ),
				'label_block'=>true,
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $this->get_customparant_terms('product_cat'),
				'default' => ['all'],
			]
		);	
		$this->end_controls_section();	
	}
	
		protected function render() {
		// get our input from the widget settings.
		$settings = $this->get_settings_for_display();
		$params['listing_type'] = $settings['listing_type'] ? $settings['listing_type'] : 'all';
		$params['orderby'] = $settings['listing_order'] ? $settings['listing_order'] : 'desc';
		$params['listing_column'] = $settings['listing_column'] ? $settings['listing_column'] : 'columns-3';	
		$params['no_of_post'] = $settings['posts_per_page'] ? (int)$settings['posts_per_page'] : 6;
		$params['categories'] = $settings['categories'] ? $settings['categories'] : 'all';
			echo maxwheels_elementor_all_products($params);
		}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
}