<?php
namespace MaxwheelsSpace\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Hero_Two extends Widget_Base {
	
	public function get_name() {
		return 'hero-two';
	}
	
	public function get_title() {
		return __( 'Hero Section 2', 'maxwheels-elementor' );
	}
	
	public function get_icon() {
		return 'maxwheels-icon';
	}

	public function get_categories() {
		return [ 'sonutheme' ];
	}
	
	public function get_script_depends() {
		return [ '' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	 
	protected function register_controls() {
		
		$this->start_controls_section(
			'section_query',
			[
				'label' => esc_html__( 'Hero Content', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'widget_type',
			[
				'label' => __( 'Shortcode Type', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'dealers',
				'label_block' =>true,
				'description' => __( 'Select shortcode type to display on the frontend.', 'maxwheels-elementor' ),
				'options' => [
					'dealers'  => __( 'Dealers', 'maxwheels-elementor' ),
					'listings' => __( 'Listings', 'maxwheels-elementor' ),
				],
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => __( 'Sub Title', 'maxwheels-elementor' ),
				'label_block' =>true,
				'default' => __( 'Subtitle Here', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'heading_text',
			[
				'label' => __( 'Main Heading', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'title' => __( 'To highligt heading use color tag eg: {color} Awesome </color>', 'maxwheels-elementor' ),
				'rows' => 3,
				'description' => __( 'Highligt heading use color tag eg: {color} Awesome </color>', 'maxwheels-elementor' ),
				'default' => __( 'Content goes here..', 'maxwheels-elementor' ),
			]
		);

		$this->add_control(
			'item_description',
			[
				'label' => __( 'Description', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 7,
				'placeholder' => __( 'Type your description here', 'maxwheels-elementor' ),
				'default' => __( 'Content goes here..', 'maxwheels-elementor' ),
			]
		);
		$this->end_controls_section();
		
		 $this->start_controls_section(
            'content_section',
            [
                'label'     => esc_html__( 'Other', 'maxwheels-elementor' ),
                'tab'       => Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
			'selection_type',
			[
				'label' => __( 'Show Dealers', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'dealers',
				'options' => [
				    'no'  => __( 'No', 'maxwheels-elementor' ),
					'dealers'  => __( 'Dealers', 'maxwheels-elementor' ),

				],
			]
		);
		
		 $this->add_control(
            'top_title',
            [
                'label'     => esc_html__( 'Title', 'maxwheels-elementor' ),
                'type'      => Controls_Manager::TEXT,
				'default' => esc_html__( 'Top Agencies', 'maxwheels-elementor' ),
				'condition' => [
                    'selection_type' => [ 'dealers']
                ],
            ]
        );
		
		$this->add_control(
			'selection_status',
			[
				'label' => __( 'Select Type', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'featured'  => __( 'Sponsored', 'maxwheels-elementor' ),
					'all' => __( 'All', 'maxwheels-elementor' ),
				],
				'condition' => [
                    'selection_type' => [ 'dealers']
                ],
			]
		);
		
		 $this->add_control(
            'limit',
            [
                'label'     => esc_html__( 'Limit', 'maxwheels-elementor' ),
                'type'      => Controls_Manager::TEXT,
				'default' => '3',
                'description'   => esc_html__( 'Number of results to show.', 'maxwheels-elementor' ),
				'condition' => [
                    'selection_type' => [ 'dealers']
                ],
            ]
        );
			
	}
	
		protected function render() {
		// get our input from the widget settings.
		$settings = $this->get_settings_for_display();
		$params['widget_type'] = $settings['widget_type'];
		$params['sub_title'] = $settings['sub_title'];
		$params['heading_text'] = $settings['heading_text'];
		$params['desc'] = $settings['item_description'];
		$params['selection_type'] = $settings['selection_type'] ? $settings['selection_type'] : 'agencies';
		$params['top_title'] = $settings['top_title'];
		$params['selection_status'] = $settings['selection_status'] ? $settings['selection_status'] : 'all';
		$params['limit'] = $settings['limit'] ? $settings['limit'] : '3';
			echo Maxwheels_elementor_hero2($params);
		}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
}