<?php
namespace MaxwheelsSpace\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Hero_Main extends Widget_Base {
	
	public function get_name() {
		return 'hero-main';
	}
	
	public function get_title() {
		return __( 'Hero Main', 'maxwheels-elementor' );
	}
	
	public function get_icon() {
		return 'maxwheels-icon';
	}

	public function get_categories() {
		return [ 'sonutheme' ];
	}
	
	public function get_script_depends() {
		return [ '' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	public function get_filter_fields()
	{
		$fields = array();
		return $fields = [
            'keyword' => esc_html__( 'Keyword', 'maxwheels-elementor' ), //input
            'type' => esc_html__( 'Make', 'maxwheels-elementor' ), //select
			'model' => esc_html__( 'Model', 'maxwheels-elementor' ), //select
			'condition' => esc_html__( 'Condition', 'maxwheels-elementor' ), //select
            'offer' => esc_html__( 'Offer Type', 'maxwheels-elementor' ), //select
            'body' => esc_html__( 'Body Type', 'maxwheels-elementor' ), //select
			'fuel' => esc_html__( 'Fuel Type', 'maxwheels-elementor' ), //select
			'year' => esc_html__( 'Year', 'maxwheels-elementor' ), //select
			'transmission' => esc_html__( 'Transmission', 'maxwheels-elementor' ), //select
			'drive' => esc_html__( 'Drive Type', 'maxwheels-elementor' ), //select
			'colors' => esc_html__( 'Colors', 'maxwheels-elementor' ), //select
			'owner' => esc_html__( 'Owner Type', 'maxwheels-elementor' ), //select
			'seller' => esc_html__( 'Seller Type', 'maxwheels-elementor' ), //select
			'price' => esc_html__( 'Price', 'maxwheels-elementor' ), //range slider
			'mileage' => esc_html__( 'Mileage', 'maxwheels-elementor' ), //range slider
            'location' => esc_html__( 'Location', 'maxwheels-elementor' ), //range slider
        ];
	}
	public function get_customparant_terms($taxonomy)
	{
		$type = array();
		$terms = get_terms( array( 'taxonomy' => $taxonomy, 'parent' => 0, 'hide_empty' => 0 ));
		if ( ! empty( $terms ) && ! is_wp_error( $terms ) )
		{
			foreach ( $terms as $term ) {
				$type[$term->slug] = $term->name . ' (' . $term->count . ')';				
			}
		}
		return $type;
	}
	 
	protected function register_controls() {
		
		$this->start_controls_section(
			'section_query',
			[
				'label' => esc_html__( 'Hero Content', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => __( 'Sub Title', 'maxwheels-elementor' ),
				'label_block' =>true,
				'default' => __( 'Subtitle Here', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'heading_text',
			[
				'label' => __( 'Main Heading', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'title' => __( 'To highligt heading use color tag eg: {color} Awesome </color>', 'maxwheels-elementor' ),
				'rows' => 3,
				'description' => __( 'Highligt heading use color tag eg: {color} Awesome </color>', 'maxwheels-elementor' ),
				'default' => __( 'Content goes here..', 'maxwheels-elementor' ),
			]
		);

		$this->add_control(
			'item_description',
			[
				'label' => __( 'Description', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 7,
				'placeholder' => __( 'Type your description here', 'maxwheels-elementor' ),
				'default' => __( 'Content goes here..', 'maxwheels-elementor' ),
			]
		);
				
		$this->end_controls_section();
		
		$this->start_controls_section(
			'types_selection',
			[
				'label' => esc_html__( 'Select Makes/Categories', 'maxwheels-elementor' ),
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'categories',
			[
				'label' => __( 'Select Make', 'maxwheels-elementor' ),
				'label_block'=>true,
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => false,
				'options' => $this->get_customparant_terms('mw-category'),
			]
		);
		$repeater->add_control(
			'image',
			[
				'label' => __( 'Image', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'description' => __( 'Recommended image size 250x300', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'list_makes',
			[
				'label' => __( 'Select Make', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ categories }}}',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_filters',
			[
				'label' => esc_html__( 'Filters', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'show_form',
			[
				'label' => __( 'Show Form', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'yes',
				'options' => [
					'no'  => 'No',
					'yes' => 'Yes',
				],
			]
		);
		$this->add_control(
            'btn_text',
            [
                'label' => __( 'Button Text', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => __( 'Search', 'maxwheels-elementor' ),
				'label_block'=>false,
            ]
        );
		$this->add_control(
            'btncolumn_size',
            [
                'label' => __( 'Button Column Size', 'maxwheels-elementor' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
				'options' => [
					'1'  => 1,
					'2' => 2,
					'3' => 3,
					'4' => 4,
					'5' => 5,
					'6' => 6,
					'7' => 7,
					'8' => 8,
					'9' => 9,
					'10' => 10,
					'11' => 11,
					'12' => 12,
				],
            ]
        );
		$this->add_control(
			'show_labels',
			[
				'label' => __( 'Hide Field Labels', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'maxwheels-elementor' ),
				'label_off' => __( 'Hide', 'maxwheels-elementor' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
			'show_dependent_fields',
			[
				'label' => __( 'Show Dependent Fields', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'placeholder' => __( 'Eg Make > Model > Varient', 'maxwheels-elementor' ),
                'default' => 'no',
				'options' => [
					'no'  => 'No',
					'yes' => 'Yes',
				],
			]
		);
		$this->add_control(
			'color_mode',
			[
				'label' => __( 'Section Color Mode', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'dark',
				'options' => [
					'white'  => 'White',
					'dark' => 'Dark',
				],
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
            'filter_type',
            [
                'label' => esc_html__( 'Filter Type', 'maxwheels-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' =>  $this->get_filter_fields(),
                'default' => 'text',
            ]
        );
		$repeater->add_control(
            'field_label',
            [
                'label' => __( 'Label', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '',
            ]
        );
		$repeater->add_control(
            'field_place',
            [
                'label' => __( 'Placeholder', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => '!in',
                            'value' => [
                                'price',
								'mileage',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'column_size',
            [
                'label' => __( 'Column Size', 'maxwheels-elementor' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
				'options' => [
					'1'  => 1,
					'2' => 2,
					'3' => 3,
					'4' => 4,
					'5' => 5,
					'6' => 6,
					'7' => 7,
					'8' => 8,
					'9' => 9,
					'10' => 10,
					'11' => 11,
					'12' => 12,
				],
            ]
        );
		$repeater->add_control(
            'min_label',
            [
                'label' => __( 'Min Price', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '1',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'price',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'max_label',
            [
                'label' => __( 'Max Price', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '1000000',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'price',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'max_interval',
            [
                'label' => __( 'Steps Interval', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '5000',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'price',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'min_label_mil',
            [
                'label' => __( 'Min Mileage', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '-1',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'mileage',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'max_label_mil',
            [
                'label' => __( 'Max Mileage', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '10000',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'mileage',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'max_interval_mil',
            [
                'label' => __( 'Steps Interval', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '5000',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'mileage',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$this->add_control(
			'list',
			[
				'label' => __( 'Select Filters', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'filter_type' => 'keyword',
						'field_label' => __( 'Keyword', 'maxwheels-elementor' ),
						'field_place' => __( 'What are you looking for...', 'maxwheels-elementor' ),
						'column_size' => '12'
					],
					[
						'filter_type' => 'type',
						'field_label' => __( 'Make', 'maxwheels-elementor' ),
						'field_place' => __( 'Select Make', 'maxwheels-elementor' ),
						'column_size' => '6'
					],
					[
						'filter_type' => 'condition',
						'field_label' => __( 'Condition', 'maxwheels-elementor' ),
						'field_place' => __( 'Eg Used', 'maxwheels-elementor' ),
						'column_size' => '6'
					],
					[
						'filter_type' => 'body',
						'field_label' => __( 'Body Type', 'maxwheels-elementor' ),
						'field_place' => __( 'Eg Sedan', 'maxwheels-elementor' ),
						'column_size' => '6'
					],
					[
						'filter_type' => 'drive',
						'field_label' => __( 'Drive Type', 'maxwheels-elementor' ),
						'field_place' => __( 'Eg AWD', 'maxwheels-elementor' ),
						'column_size' => '6'
					],
					[
						'filter_type' => 'price',
						'field_label' => __( 'Price Range', 'maxwheels-elementor' ),
						'min_label' => '1',
						'max_label' => '100',
						'max_interval' => '10',
						'column_size' => '12'
					],
				],
				'title_field' => '{{{ field_label }}}',
				
			]
		);
		$this->end_controls_section();
		
		
		
	}
	
		protected function render() {
		// get our input from the widget settings.
		$settings = $this->get_settings_for_display();
		$params['heading_text'] = $settings['heading_text'];
		$params['desc'] = $settings['item_description'];
		$params['sub_title'] = $settings['sub_title'];	
		$params['btn_text'] = $settings['btn_text'];
		$params['filter_array'] = $settings['list'];
		$params['show_labels'] = $settings['show_labels'];
		$params['btncolumn_size'] = $settings['btncolumn_size'];
		$params['dependent_fields'] = $settings['show_dependent_fields'];
		$params['show_form'] = $settings['show_form'];
		$params['color_mode'] = $settings['color_mode'];
		$blocks = array();
		if(!empty($settings['list_makes']))
		{
			foreach (  $settings['list_makes'] as $item ) {
				$blocks[] = array(
					'type_slug' => $item['categories'],
					'image' => $item['image']['url'] ? $item['image']['url'] : '',
				);
			}
		}
		$params['types'] = $blocks;	
			echo maxwheels_elementor_main($params);
			if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) : ?>
         <script>
		 	jQuery('.search-selects').select2({
				 width:'100%',
	 			theme: "classic",
			});
			 if ( jQuery( ".js-range-slider-price-home" ).length )
					{
						var $servicesRange = jQuery(".js-range-slider-price-home"),
						$servicesInputFrom = jQuery(".js-input-from"),
						$servicesInputTo = jQuery(".js-input-to"),
						instance,
						min = jQuery(this).prop("value"),
						max = jQuery(this).prop("value"),
						from = 0,
						to = 0;
						$servicesRange.ionRangeSlider({
							skin: "round",
							type: "double",
						});
						instance = $servicesRange.data("ionRangeSlider");
					}
				if ( jQuery( ".js-range-slider-mileage-home" ).length > 0)
				{
					 jQuery(".js-range-slider-mileage-home").ionRangeSlider({
							skin: "round",
					});    
				}
		 </script>    
        <?php endif; 
		}
/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
}