<?php
namespace MaxwheelsSpace\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Makes4 extends Widget_Base {
	
	public function get_name() {
		return 'all-makes-4';
	}
	
	public function get_title() {
		return __( 'Makes With SubCategories', 'maxwheels-elementor' );
	}
	
	public function get_icon() {
		return 'maxwheels-icon';
	}

	public function get_categories() {
		return [ 'sonutheme' ];
	}
	
	public function get_script_depends() {
		return [ '' ];
	}

	public function get_customparant_terms($taxonomy)
	{
		$type = array();
		$terms = get_terms( array( 'taxonomy' => $taxonomy, 'parent' => 0, 'hide_empty' => 0 ));
		if ( ! empty( $terms ) && ! is_wp_error( $terms ) )
		{
			foreach ( $terms as $term ) {
				$type[$term->slug] = $term->name . ' (' . $term->count . ')';				
			}
		}
		return $type;
	}	 
	 
	protected function register_controls() {
		$type = array();
		$this->start_controls_section(
			'types_selection',
			[
				'label' => esc_html__( 'Select Makes', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Sub Category Limit', 'maxwheels-elementor' ),
				'label_block' =>true,
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 4,
			]
		);
		$this->add_control(
			'hide_logo',
			[
				'label' => __( 'Hide Make Logo', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'no',
				'options' => [
					'yes'  => 'Yes',
					'no' => 'No',
				],
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'categories',
			[
				'label' => __( 'Select Type', 'maxwheels-elementor' ),
				'label_block'=>true,
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => false,
				'options' =>  $this->get_customparant_terms('mw-category'),
				'default' => ['all'],
			]
		);
		$repeater->add_control(
			'image',
			[
				'label' => __( 'Icon', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'description' => __( 'Recommended icon size 128x128', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
			'list',
			[
				'label' => __( 'Select Makes', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ categories }}}',
			]
		);
		$this->end_controls_section();
	}
	
		protected function render() {
		// get our input from the widget settings.
		$blocks = array();
		$settings = $this->get_settings_for_display();
		$params['no_of_post'] = $settings['posts_per_page'] ? (int)$settings['posts_per_page'] : 4;
		$params['logo'] = $settings['hide_logo'] ? $settings['hide_logo'] : 'no';
		if(!empty($settings['list']))
		{
			foreach (  $settings['list'] as $item ) {
				$blocks[] = array(
					'type_slug' => $item['categories'],
					'image' => $item['image']['url'] ? $item['image']['url'] : '',
				);
			}
		}
		$params['types'] = $blocks;
			echo maxwheels_elementor_all_makes_four($params);
		}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
}