<?php
namespace MaxwheelsSpace\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class SearchBuilder extends Widget_Base {
	
	public function get_name() {
		return 'search-builder1';
	}
	
	public function get_title() {
		return __( 'Advanced Search Builder', 'maxwheels-elementor' );
	}
	
	public function get_icon() {
		return 'maxwheels-icon';
	}

	public function get_categories() {
		return [ 'sonutheme' ];
	}
	
	public function get_script_depends() {
		return [ '' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	public function get_filter_fields()
	{
		$fields = array();
		return $fields = [
            'keyword' => esc_html__( 'Keyword', 'maxwheels-elementor' ), //input
            'type' => esc_html__( 'Make', 'maxwheels-elementor' ), //select
			'model' => esc_html__( 'Model', 'maxwheels-elementor' ), //select
			'condition' => esc_html__( 'Condition', 'maxwheels-elementor' ), //select
            'offer' => esc_html__( 'Offer Type', 'maxwheels-elementor' ), //select
            'body' => esc_html__( 'Body Type', 'maxwheels-elementor' ), //select
			'fuel' => esc_html__( 'Fuel Type', 'maxwheels-elementor' ), //select
			'year' => esc_html__( 'Year', 'maxwheels-elementor' ), //select
			'transmission' => esc_html__( 'Transmission', 'maxwheels-elementor' ), //select
			'drive' => esc_html__( 'Drive Type', 'maxwheels-elementor' ), //select
			'colors' => esc_html__( 'Colors', 'maxwheels-elementor' ), //select
			'owner' => esc_html__( 'Owner Type', 'maxwheels-elementor' ), //select
			'seller' => esc_html__( 'Seller Type', 'maxwheels-elementor' ), //select
			'price' => esc_html__( 'Price', 'maxwheels-elementor' ), //range slider
			'mileage' => esc_html__( 'Mileage', 'maxwheels-elementor' ), //range slider
            'location' => esc_html__( 'Location', 'maxwheels-elementor' ), //range slider
        ];
	} 
	  
	protected function register_controls() {
		$this->start_controls_section(
			'section_filters',
			[
				'label' => esc_html__( 'Filters', 'maxwheels-elementor' ),
			]
		);
		$this->add_control(
            'sec_text',
            [
                'label' => __( 'Section Text', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => __( 'Looking For A Car?', 'maxwheels-elementor' ),
				'label_block'=>true,
				'placeholder' => __( 'To highligt heading use color tag eg: {color} Awesome </color>', 'maxwheels-elementor' ),
            ]
        );
		$this->add_control(
            'btn_text',
            [
                'label' => __( 'Button Text', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => __( 'Search', 'maxwheels-elementor' ),
				'label_block'=>true,
            ]
        );
		$this->add_control(
            'total_listings',
            [
                'label' => __( 'Total Listings Text', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => __( 'Cars Available', 'maxwheels-elementor' ),
				'label_block'=>true,
            ]
        );
		$this->add_control(
            'btncolumn_size',
            [
                'label' => __( 'Button Column Size', 'maxwheels-elementor' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
				'options' => [
					'1'  => 1,
					'2' => 2,
					'3' => 3,
					'4' => 4,
					'5' => 5,
					'6' => 6,
					'7' => 7,
					'8' => 8,
					'9' => 9,
					'10' => 10,
					'11' => 11,
					'12' => 12,
				],
            ]
        );
		$this->add_control(
			'show_labels',
			[
				'label' => __( 'Hide Field Labels', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'maxwheels-elementor' ),
				'label_off' => __( 'Hide', 'maxwheels-elementor' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'color_mode',
			[
				'label' => __( 'Section Color Mode', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'white',
				'options' => [
					'white'  => 'White',
					'dark' => 'Dark',
				],
			]
		);
		$this->add_control(
			'show_dependent_fields',
			[
				'label' => __( 'Show Dependent Fields', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'placeholder' => __( 'Eg Make > Model > Varient', 'maxwheels-elementor' ),
                'default' => 'no',
				'options' => [
					'no'  => 'No',
					'yes' => 'Yes',
				],
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
            'filter_type',
            [
                'label' => esc_html__( 'Filter Type', 'maxwheels-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' =>  $this->get_filter_fields(),
                'default' => 'text',
            ]
        );
		$repeater->add_control(
            'field_label',
            [
                'label' => __( 'Label', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '',
            ]
        );
		$repeater->add_control(
            'field_place',
            [
                'label' => __( 'Placeholder', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => '!in',
                            'value' => [
                                'price',
								'mileage',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'column_size',
            [
                'label' => __( 'Column Size', 'maxwheels-elementor' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
				'options' => [
					'1'  => 1,
					'2' => 2,
					'3' => 3,
					'4' => 4,
					'5' => 5,
					'6' => 6,
					'7' => 7,
					'8' => 8,
					'9' => 9,
					'10' => 10,
					'11' => 11,
					'12' => 12,
				],
            ]
        );
		$repeater->add_control(
            'min_label',
            [
                'label' => __( 'Min Price', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '1',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'price',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'max_label',
            [
                'label' => __( 'Max Price', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '1000000',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'price',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'max_interval',
            [
                'label' => __( 'Steps Interval', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '5000',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'price',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'min_label_mil',
            [
                'label' => __( 'Min Mileage', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '-1',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'mileage',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'max_label_mil',
            [
                'label' => __( 'Max Mileage', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '10000',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'mileage',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$repeater->add_control(
            'max_interval_mil',
            [
                'label' => __( 'Steps Interval', 'maxwheels-elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => '5000',
				'conditions' => [
                    'terms' => [
                        [
                            'name' => 'filter_type',
                            'operator' => 'in',
                            'value' => [
                                'mileage',
                            ],
                        ],
                    ],
                ],
            ]
        );
		$this->add_control(
			'list',
			[
				'label' => __( 'Select Filters', 'maxwheels-elementor' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'filter_type' => 'type',
						'field_label' => __( 'Make', 'maxwheels-elementor' ),
						'field_place' => __( 'Select Make', 'maxwheels-elementor' ),
					],
					[
						'filter_type' => 'model',
						'field_label' => __( 'Model', 'maxwheels-elementor' ),
						'field_place' => __( 'Select Model', 'maxwheels-elementor' ),
					],
					[
						'filter_type' => 'year',
						'field_label' => __( 'Year', 'maxwheels-elementor' ),
						'field_place' => __( 'Select Year', 'maxwheels-elementor' ),
					],
				],
				'title_field' => '{{{ field_label }}}',
				
			]
		);
		$this->end_controls_section();
	}
	
		protected function render() {
		// get our input from the widget settings.
		$settings = $this->get_settings_for_display();
		$params['sec_text'] = $settings['sec_text'];
		$params['btn_text'] = $settings['btn_text'];
		$params['total_listings'] = $settings['total_listings'] ? $settings['total_listings'] : 'Listings' ;
		$params['show_labels'] = $settings['show_labels'];
		$params['btncolumn_size'] = $settings['btncolumn_size'];
		$params['color_mode'] = $settings['color_mode'];
		$params['dependent_fields'] = $settings['show_dependent_fields'];
		$params['filter_array'] = $settings['list'];
			echo Maxwheels_elementor_search_builder($params);
			if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) : ?>
            <script>
				if ( jQuery( ".js-range-slider-price-home" ).length )
					{
						var $servicesRange = jQuery(".js-range-slider-price-home"),
						$servicesInputFrom = jQuery(".js-input-from"),
						$servicesInputTo = jQuery(".js-input-to"),
						instance,
						min = jQuery(this).prop("value"),
						max = jQuery(this).prop("value"),
						from = 0,
						to = 0;
						$servicesRange.ionRangeSlider({
							skin: "round",
							type: "double",
						});
						instance = $servicesRange.data("ionRangeSlider");
					}
				if ( jQuery( ".js-range-slider-mileage-home" ).length > 0)
				{
					 jQuery(".js-range-slider-mileage-home").ionRangeSlider({
							skin: "round",
					});    
				}
			</script>    
        <?php endif; 	
		}
/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
}