<?php
class RealPage_Meta_Box {

	public function __construct() {

		if ( is_admin() ) {
			add_action( 'load-post.php',     array( $this, 'init_page_metabox' ) );
			add_action( 'load-post-new.php', array( $this, 'init_page_metabox' ) );
		}

	}

	public function init_page_metabox() {

		add_action( 'add_meta_boxes', array( $this, 'add_page_metabox'  )        );
		add_action( 'save_post',      array( $this, 'save_page_metabox' ), 10, 2 );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_scripts_styles')  );
		add_action( 'admin_footer',          array( $this, 'color_field_js' )      );
		

	}

	public function add_page_metabox() {
		add_meta_box(
			'page_info',
			__( 'Page Settings', 'maxwheels-framework' ),
			array( $this, 'render_page_metabox' ),
			'page',
			'advanced',
			'default'
		);
	}

	public function render_page_metabox( $post ) {

		// Add nonce for security and authentication.
		wp_nonce_field( 'custom_page_nonce_action', 'custom_page_nonce' );
		// Retrieve an existing value from the database.
		$show_bread = get_post_meta( $post->ID, 'show_page_bread', true );
		$show_trans = get_post_meta( $post->ID, 'show_trans_header', true );
		$primary_color = get_post_meta( $post->ID, 'primary_color', true );
		$logo = get_post_meta( $post->ID, 'mw_page_log', true );

		// Set default values.
		if( empty( $show_bread ) ) $show_bread = '';
		if( empty( $show_trans ) ) $show_trans = '';
		if( empty( $primary_color ) ) $primary_color = '#fff';
		if( empty( $logo ) ) $logo = '';

		// Form fields.
		echo '<table class="form-table">';
		echo '	<tr>';
		echo '		<th><label for="breadcrumb">' . __( 'Breadcrumb', 'maxwheels-framework' ) . '</label></th>';
		echo '		<td>';
		echo '			<input type="checkbox" id="breadcrumb" name="show_bread" value="1" ' . checked( $show_bread, '1', false ) . '> ';
		echo '			<span class="description">' . __( 'Hide breadcrumb?', 'maxwheels-framework' ) . '</span>';
		echo '		</td>';
		echo '	</tr>';
		
		echo '	<tr>';
		echo '		<th><label for="trans_header">' . __( 'Transparent Header', 'maxwheels-framework' ) . '</label></th>';
		echo '		<td>';
		echo '			<input type="checkbox" id="trans_header" name="show_trans" value="1" ' . checked( $show_trans, '1', false ) . '> ';
		echo '			<span class="description">' . __( 'Mark Header As Transparent?', 'maxwheels-framework' ) . '</span>';
		echo '			<p class="description">' . __( 'Transparent Header will only work on home pages only', 'maxwheels-framework' ) . '</p>';
		echo '		</td>';
		echo '	</tr>';
		
		echo '	<tr>';
		echo '		<th><label for="primary_color" >' . __( 'Transparent Menu Color', 'maxwheels-framework' ) . '</label></th>';
		echo '		<td>';
		echo '			<input type="text" id="primary_color" name="primary_color"  value="' . esc_attr__( $primary_color ) . '">';
		echo '			<p class="description">' . __( 'Select primary color', 'maxwheels-framework' ) . '</p>';
		echo '		</td>';
		echo '	</tr>';
		echo '	<tr>';
		echo '		<th><label for="sgr_meta_slider_sc" class="aw_upload_image_button">' . __( 'Header Logo', 'maxwheels-framework' ) . '</label></th>';
		echo '		<td>';
		echo '			<a href="#" class="aw_upload_image_button button button-secondary">' . __( 'Select Logo', 'maxwheels-framework' ) . '</a>
						<input type="hidden" name="aw_custom_image" id="aw_custom_image" value="'.$logo.'">';
		
		echo '		</td>';
		echo '	</tr>';
		
		echo '</table>';

	}

	public function save_page_metabox( $post_id, $post ) {
		// Sanitize user input.
		$show_bread = isset( $_POST[ 'show_bread' ] ) ? '1' : '0';
		$show_trans = isset( $_POST[ 'show_trans' ] ) ? '1' : '0';
		$aw_custom_image = isset( $_POST[ 'aw_custom_image' ] ) ? $_POST[ 'aw_custom_image' ] : '';
		$primary_color = isset( $_POST[ 'primary_color' ] ) ? sanitize_text_field( $_POST[ 'primary_color' ] ) : '';
		// Update the meta field in the database.
		update_post_meta( $post_id, 'show_page_bread', $show_bread );
		update_post_meta( $post_id, 'show_trans_header', $show_trans );
		update_post_meta( $post_id, 'primary_color', $primary_color );
		update_post_meta( $post_id, 'mw_page_log', $aw_custom_image );
		
	}
	
	public function load_scripts_styles() {

		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_media();
	}
	
	
	public function color_field_js() {

		// Print js only once per page
		if ( did_action( 'RealPage_Meta_Box_color_picker_js' ) >= 1 ) {
			return;
		}

		?>
		<script type="text/javascript">
			jQuery(document).ready(function($){
				$('#primary_color').wpColorPicker();
			});
			
			
			 jQuery('body').on('click', '.aw_upload_image_button', function(e){
        e.preventDefault();
  
        var button = jQuery(this),
        aw_uploader = wp.media({
            title: 'Custom image',
            library : {
                uploadedTo : wp.media.view.settings.post.id,
                type : 'image'
            },
            button: {
                text: 'Use this image'
            },
            multiple: false
        }).on('select', function() {
            var attachment = aw_uploader.state().get('selection').first().toJSON();
			console.log(attachment);
            jQuery('#aw_custom_image').val(attachment.id);
        })
        .open();
    });
		</script>
		<?php
		do_action( 'RealPage_Meta_Box_color_picker_js', $this );

	}
}
new RealPage_Meta_Box();

//woocommerce packages
if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))) || class_exists( 'WooCommerce' ))
{
    
   
/* 
 * Add New Product Type to Select Dropdown
 */
add_filter( 'product_type_selector', 'maxwheels_framework_add_custom_product_type' );
function maxwheels_framework_add_custom_product_type( $types ){
    $types[ 'maxwheels_packages' ] = __( 'Maxwheels Listing Packages', 'maxwheels-framework' );
	$types[ 'maxwheels_profile_packages' ] = __( 'Maxwheels Profile Plans', 'maxwheels-framework' );
    return $types;
}
 
/* 
 * Add New Product Type Class
 */
add_action( 'init', 'maxwheels_framework_create_custom_product_type' );
add_action( 'init', 'maxwheels_framework_create_custom_product_type_plans' );	
function maxwheels_framework_create_custom_product_type(){
    class WC_Product_Custom extends WC_Product {
        public function get_type() {
            return 'maxwheels_packages';
        }
    }
}
function maxwheels_framework_create_custom_product_type_plans(){
    class WC_Product_Custom_Plans extends WC_Product {
        public function get_type() {
			return 'maxwheels_profile_packages';
        }
    }
}	
/* 
 * Load New Product Type Class
 */
add_filter( 'woocommerce_product_class', 'maxwheels_framework_woocommerce_product_class', 10, 2 );
function maxwheels_framework_woocommerce_product_class( $classname, $product_type ) {
    if ( $product_type == 'maxwheels_packages' )
	{ 
        $classname = 'WC_Product_Custom';
    }
	if ( $product_type == 'maxwheels_profile_packages' )
	{ 
        $classname = 'WC_Product_Custom_Plans';
    }
    return $classname;
} 
add_action('admin_footer', 'maxwheels_framework_custom_product_admin_custom_js');
function maxwheels_framework_custom_product_admin_custom_js()
{
    if ('product' != get_post_type()) :
        return;
    endif;
    ?>
    <script type='text/javascript'>
        jQuery(document).ready(function () {
            //for Price tab
            jQuery('#maxwheels_product').hide();
            jQuery('.options_group.pricing').addClass('show_if_maxwheels_packages').show();
            //for Inventory tab
            jQuery('.inventory_options').addClass('show_if_maxwheels_packages').show();
            jQuery('#inventory_product_data ._manage_stock_field').addClass('show_if_maxwheels_packages').show();
            jQuery('#inventory_product_data ._sold_individually_field').parent().addClass('show_if_maxwheels_packages').show();
            jQuery('#inventory_product_data ._sold_individually_field').addClass('show_if_maxwheels_packages').show();
            jQuery('#product-type').on('change', function ()
            {
                if (jQuery(this).val() == 'maxwheels_packages')
                {
                   jQuery('#maxwheels_product').show();
				   jQuery('#maxwheels_profile_plans').hide();
				   jQuery('#postdivrich').hide();
				   jQuery('#postexcerpt').hide();
				   jQuery('#product_catdiv').hide();
				   jQuery('#tagsdiv-product_tag').hide();
				   jQuery('#pageparentdiv').hide();
				   jQuery('#postimagediv').hide();
				   jQuery('#woocommerce-product-images').hide();
                }
				else if (jQuery(this).val() == 'maxwheels_profile_packages')
				{
					jQuery('#maxwheels_product').hide();
					jQuery('#maxwheels_profile_plans').show();
					jQuery('#postdivrich').hide();
					jQuery('#postexcerpt').hide();
					jQuery('#product_catdiv').hide();
					jQuery('#tagsdiv-product_tag').hide();
					jQuery('#pageparentdiv').hide();
				   jQuery('#postimagediv').hide();
				   jQuery('#woocommerce-product-images').hide();
				}
                else
                {
                    jQuery('#maxwheels_product').hide();
					jQuery('#maxwheels_profile_plans').hide();
					jQuery('#postdivrich').show();
					jQuery('#postexcerpt').show();
					jQuery('#product_catdiv').show();
					jQuery('#tagsdiv-product_tag').show();
					jQuery('#pageparentdiv').show();
				   jQuery('#postimagediv').show();
				   jQuery('#woocommerce-product-images').show();
                }
            });
			
			//for profile plans
			jQuery('#maxwheels_profile_plans').hide();
			jQuery('.options_group.pricing').addClass('show_if_maxwheels_profile_packages').show();
			jQuery('#product-type').trigger('change');
        });
    </script>
    <?php
}
	
if (!function_exists('maxwheels_framework_my_commonPriceHtml')) 
{
    function maxwheels_framework_my_commonPriceHtml($price_amt, $regular_price, $sale_price)
	{
        //if product is in sale
		$html_price = '';
        if (($price_amt == $sale_price) && ($sale_price != 0)) {
            $html_price .=  wc_price((int)$sale_price);
            $html_price .= '<span class="special-discount"><del>' . wc_price((int)$regular_price) . '</del></span>';
        }
        //in sale but free
        else if (($price_amt == $sale_price) && ($sale_price == 0)) {
            $html_price .= '';
            $html_price .= '<del>' . wc_price((int)$regular_price) . '</del>';
        }
        //not is sale
        else if (($price_amt == $regular_price) && ($regular_price != 0)) {
            $html_price .=  wc_price((int)$regular_price);
        }
        //for free product
        else if (($price_amt == $regular_price) && ($regular_price == 0)) {
            $html_price .= wc_price((int)$regular_price);
        }
		else
		{
			$html_price = '';
		}
        return $html_price;
    }
}
add_filter('woocommerce_get_price_html', 'maxwheels_framework_simple_product_price_html', 10, 2);
function maxwheels_framework_simple_product_price_html($price, $product)
{
        $regular_price = $product->get_regular_price();
        $sale_price = $product->get_sale_price();
        $price_amt = $product->get_price();
        return maxwheels_framework_my_commonPriceHtml($price_amt, $regular_price, $sale_price);
}

	
//Woocommerce checkout fields
	function maxwheels_framework_add_woo_bootstrap_input_classes( $args, $key, $value = null ) {
        // Start field type switch case
        switch ( $args['type'] ) {

            case "select" :  /* Targets all select input type elements, except the country and state select input types */
                $args['class'][] = 'form-group'; // Add a class to the field's html element wrapper - woocommerce input types (fields) are often wrapped within a <p></p> tag
                $args['input_class'] = array('form-control', 'input-lg'); // Add a class to the form input itself
                //$args['custom_attributes']['data-plugin'] = 'select2';
                $args['label_class'] = array('control-label');
                $args['custom_attributes'] = array( 'data-plugin' => 'select2', 'data-allow-clear' => 'true', 'aria-hidden' => 'true',  ); // Add custom data attributes to the form input itself
            break;

            case 'country' : /* By default WooCommerce will populate a select with the country names - $args defined for this specific input type targets only the country select element */
                $args['class'][] = 'form-group single-country';
                $args['label_class'] = array('control-label');
            break;

            case "state" : /* By default WooCommerce will populate a select with state names - $args defined for this specific input type targets only the country select element */
                $args['class'][] = 'form-group'; // Add class to the field's html element wrapper
                $args['input_class'] = array('form-control', 'input-lg'); // add class to the form input itself
                //$args['custom_attributes']['data-plugin'] = 'select2';
                $args['label_class'] = array('control-label');
                $args['custom_attributes'] = array( 'data-plugin' => 'select2', 'data-allow-clear' => 'true', 'aria-hidden' => 'true',  );
            break;
            case "password" :
            case "text" :
            case "email" :
            case "tel" :
            case "number" :
                $args['class'][] = 'form-group';
                //$args['input_class'][] = 'form-control input-lg'; // will return an array of classes, the same as bellow
                $args['input_class'] = array('form-control', 'input-lg');
                $args['label_class'] = array('control-label');
            break;
            case 'textarea' :
                $args['input_class'] = array('form-control', 'input-lg');
                $args['label_class'] = array('control-label');
            break;

            case 'checkbox' :
            break;

            case 'radio' :
            break;

            default :
                $args['class'][] = 'form-group';
                $args['input_class'] = array('form-control', 'input-lg');
                $args['label_class'] = array('control-label');
            break;
        }

        return $args;
    }
    add_filter('woocommerce_form_field_args','maxwheels_framework_add_woo_bootstrap_input_classes',10,3);
	
}


