<?php
// Ajax handler for property submission
if(in_array('advanced-custom-fields/acf.php', apply_filters('active_plugins', get_option('active_plugins'))) && class_exists('ACF'))
{
	add_filter( 'acf/save_post', 'maxwheels_framework_acf_clear_object_cache' );
	function maxwheels_framework_acf_clear_object_cache( $post_id ) {
		if ( empty( $_POST['acf'] ) ) {
			return;
		}
		// clear post related cache
		clean_post_cache( $post_id );
		// clear ACF cache
		$acf_cache_cleared = wp_cache_delete( 'acf-post', 'acf' );
		// clear all cache if no specific key/group is found
		if ( !$acf_cache_cleared ) {
			wp_cache_flush();
		}
	}
}
// Ajax handler for property submission
add_action( 'wp_ajax_mw_submission', 'maxwheels_framework_mw_submission' );
add_action( 'wp_ajax_nopriv_mw_submission', 'maxwheels_framework_mw_submission' );
if (!function_exists ( 'maxwheels_framework_mw_submission' ))
{
	function maxwheels_framework_mw_submission()
	{
		$params = array();
        global $maxwheels_options;
		parse_str($_POST['collect_data'], $params);
		if(maxwheels_framework_get_options('mw_demo') == 1 && !is_super_admin( get_current_user_id()))
		{
			$return = array('message' => esc_html__( 'Disable for Demo.', 'maxwheels-framework' ));
			wp_send_json_error($return);
		}
		if(!wp_verify_nonce($_POST['security'], 'check-security'))
		{
			 $return = array('message' => esc_html__('Invalid security token sent.', 'maxwheels-framework'));
      		 wp_send_json_error($return);
   		}
        if( !is_user_logged_in() )
        {
            $return = array('message' => esc_html__('You must be logged in to submit a listings.', 'maxwheels-framework'));
      		wp_send_json_error($return);
        }
        else
		{
            $user_id = get_current_user_id();
            $trim_id = $trim = $model_id = $model_name = $varient_id = $varient_name = $make_id  = $make_name = $makes = $model =  $varient = '';
            //categories
            $cat_levels = array();
            $title_name = array();
            $year       = isset( $params[ 'year' ] ) ? sanitize_text_field( $params[ 'year' ] ) : '';
            $title_name[]  =  $year;
            if(isset($params['cat-parent']) && $params['cat-parent'] !="")
            {
                $makes         =   sanitize_text_field($params['cat-parent']);
                $make_id       =   get_term_by('slug', $makes, 'mw-category');
                $cat_levels[]  =   $make_id->term_id;
                $title_name[]  =   $make_id->name;
            }
            if(isset($params['level-1']) && $params['level-1'] !="")
            {
                $model          = sanitize_text_field($params['level-1']);
                $model_id       = get_term_by('slug', $model, 'mw-category');
                $cat_levels[]   = $model_id->term_id;
                $title_name[]  =   $model_id->name;
            }
            if(isset($params['level-2']) && $params['level-2'] !="")
            {
                $varient          = sanitize_text_field($params['level-2']);
                $varient_id       = get_term_by('slug', $varient, 'mw-category');
                $cat_levels[]     = $varient_id->term_id;
                $title_name[]  =   $varient_id->name;
            }
            if(isset($params['level-3']) && $params['level-3'] !="")
            {
                $trim             = sanitize_text_field($params['level-3']);
                $trim_id          = get_term_by('slug', $trim, 'mw-category');
                $varient_name     = $trim_id->name;
                $cat_levels[]     = $trim_id->term_id;
            }
            if($maxwheels_options['mw_auto_generated_title'] == 1) {
                $my_title = implode(" ", $title_name);
            }else{
                $my_title = isset( $params[ 'listing-title' ] ) ? sanitize_text_field( $params['listing-title' ] ) : '';
            }

			$conditions = isset( $params[ 'conditions' ] ) ? sanitize_text_field( $params['conditions' ] ) : '';
			$bodytype   = isset( $params[ 'bodytype' ] ) ? sanitize_text_field( $params[ 'bodytype' ] ) : '';
			$transmission = isset( $params[ 'transmission' ] ) ? sanitize_text_field( $params[ 'transmission' ] ) : '';
			$fuel = isset( $params[ 'fuel' ] ) ? sanitize_text_field( $params[ 'fuel' ] ) : '';
			$plate = isset( $params[ 'plate' ] ) ? sanitize_text_field( $params[ 'plate' ] ) : '';
			$vin = isset( $params[ 'vin' ] ) ? sanitize_text_field( $params[ 'vin' ] ) : '';
			$registration = isset( $params[ 'registration' ] ) ? sanitize_text_field( $params[ 'registration' ] ) : '';
			$price = isset( $params[ 'price' ] ) ? sanitize_text_field( $params[ 'price' ] ) : '';
			$mileage = isset( $params[ 'mileage' ] ) ? sanitize_text_field( $params[ 'mileage' ] ) : '';
			$drive = isset( $params[ 'drive' ] ) ? sanitize_text_field( $params[ 'drive' ] ) : '';
			$extrtior = isset( $params[ 'extrtior' ] ) ? sanitize_text_field( $params[ 'extrtior' ] ) : '';
			$interior = isset( $params[ 'interior' ] ) ? sanitize_text_field( $params[ 'interior' ] ) : '';
			$keys = isset( $params[ 'keys' ] ) ? sanitize_text_field( $params[ 'keys' ] ) : '';
			$highway = isset( $params[ 'highway' ] ) ? sanitize_text_field( $params[ 'highway' ] ) : '';
			$city = isset( $params[ 'city' ] ) ? sanitize_text_field( $params[ 'city' ] ) : '';
			$enginesize = isset( $params[ 'enginesize' ] ) ? sanitize_text_field( $params[ 'enginesize' ] ) : '';
			$owners = isset( $params[ 'owners' ] ) ? sanitize_text_field( $params[ 'owners' ] ) : '';
			$type = isset( $params[ 'type' ] ) ? sanitize_text_field( $params[ 'type' ] ) : '';
			$approval = 'draft';
			// Bad words filteration
			$words		  =	explode( ',', maxwheels_framework_get_options('mw_badwords') );
			$replace	  =	maxwheels_framework_get_options('mw_badwords_replace');
			$final_title  =	maxwheels_framework_badwords_filter($my_title, $replace, $words);


            if(!empty($params['listing_id']) && $params['is_edit'] && $params['is_edit'] == 'yes')
            {

                $mw_id = $params['listing_id'];
                $approval = maxwheels_framework_get_listing_status($mw_id,true);

                $my_post = array(
				  'ID'           => $mw_id,
				  'post_title'   => wp_strip_all_tags($final_title),
				  'post_status'   => $approval,
				  'post_type' 	=> 'mx-listings'
  				);

  				wp_update_post( $my_post );
            }
            else
            {

                $my_post = array(
                  'post_title'   => wp_strip_all_tags($final_title),
                  'post_content' => "",
                  'post_status'   => $approval,
                  'post_author'   => $user_id,
                  'post_type' 	=> 'mx-listings'
                );

                $mw_id = wp_insert_post($my_post);

            }
            if($mw_id)
			 {
                $owner_id = get_post_field( 'post_author', $mw_id );
                $user_role_type = get_user_meta($owner_id, 'user_role_type', true);
                update_post_meta($mw_id, 'mw_auth_seller_type', $user_role_type);
                 update_post_meta($mw_id, 'mw_status', '1');

				if (get_post_meta($mw_id, 'mw_is_feature_listing', true ) == "1")
				{
				}
				else
				{
					update_post_meta($mw_id, 'mw_is_feature_listing', '0');
				}


                 //all categories
                wp_set_object_terms($mw_id, $cat_levels, 'mw-category');
				update_post_meta($mw_id, 'mw_all_cats', $cat_levels);
				//conditions
				wp_set_object_terms($mw_id, $conditions, 'mw-condition');
				update_post_meta($mw_id, 'mw_condition', $conditions);
				//year
				wp_set_object_terms($mw_id, $year, 'mw-year');
				update_post_meta($mw_id, 'mw_year', $year);
				//bodytype
				wp_set_object_terms($mw_id, $bodytype, 'mw-bodytype');
				update_post_meta($mw_id, 'mw_bodytype', $bodytype);
                //transmission
				wp_set_object_terms($mw_id, $transmission, 'mw-transmission');
				update_post_meta($mw_id, 'mw_transmission', $transmission);
                //fuel
				wp_set_object_terms($mw_id, $fuel, 'mw-fuel');
				update_post_meta($mw_id, 'mw_fueltype', $fuel);
                //number place
                update_post_meta($mw_id, 'mw_numberplate', $plate);
                //vin number
                update_post_meta($mw_id, 'mw_vin_number', $vin);
                //registration time
                update_post_meta($mw_id, 'mw_registration', $registration);
                //asking price
                update_post_meta($mw_id, 'mw_price', $price); 
                //milage (km)
                update_post_meta($mw_id, 'mw_mileage', $mileage);
                //drive
				wp_set_object_terms($mw_id, $drive, 'mw-drive');
				update_post_meta($mw_id, 'mw_drive', $drive);
                //extrtior
                    wp_set_object_terms($mw_id, $extrtior, 'mw-exterior-color');
				update_post_meta($mw_id, 'mw_extrtior', $extrtior);
                //interior
				wp_set_object_terms($mw_id, $interior, 'mw-interior-color');
				update_post_meta($mw_id, 'mw_interior', $interior);
                //keys
                update_post_meta($mw_id, 'mw_keys', $keys); 
                //highway
                update_post_meta($mw_id, 'mw_highway', $highway); 
                //city
                update_post_meta($mw_id, 'mw_city', $city); 
                //enginesize
                update_post_meta($mw_id, 'mw_enginesize', $enginesize);
                //owners
				wp_set_object_terms($mw_id, $owners, 'mw-owners');
				update_post_meta($mw_id, 'mw_owners', $owners);
				//types/labels
				wp_set_object_terms($mw_id, $type, 'mw-Labels');
				update_post_meta($mw_id, 'mw_type', $type);
				
				//saving custom fields
				if (isset($params['acf']) && $params['acf'] != '' && class_exists('ACF')) 
				{

					maxwheels_framework_acf_clear_object_cache($mw_id);
					acf_update_values($params['acf'], $mw_id);
        		}
                if(!empty($mw_id)  && $params['is_edit'] == 'yes')
                {
                    $link =  maxwheels_framework_get_link('page-submit-listings-step2.php').'?edit_listing='.$mw_id.'';
                }
                else
                {
                    if (!session_id())
                    {
                        session_start();
                        $_SESSION['listing-id'] = $mw_id;
                    }
                    $link =  maxwheels_framework_get_link('page-submit-listings-step2.php');
                }
				$return = array('referral' => $link);
      		 	wp_send_json_success($return);
			 }
  		}
	}
}


// Ajax handler for property submission step 2
add_action( 'wp_ajax_mw_submission_two', 'maxwheels_framework_mw_submission_step2' );
add_action( 'wp_ajax_nopriv_mw_submission_two', 'maxwheels_framework_mw_submission_step2' );
if (!function_exists ( 'maxwheels_framework_mw_submission_step2' ))
{
	function maxwheels_framework_mw_submission_step2()
	{
        $params = array();
        $author_id=get_current_user_id();
        parse_str($_POST['collect_data'], $params);
		if(maxwheels_framework_get_options('mw_demo') == 1 && !is_super_admin( get_current_user_id()))
		{
			$return = array('message' => esc_html__( 'Disable for Demo.', 'maxwheels-framework' ));
			wp_send_json_error($return);
		}
		if(!wp_verify_nonce($_POST['security'], 'check-security'))
		{
			 $return = array('message' => esc_html__('Invalid security token sent.', 'maxwheels-framework'));
      		 wp_send_json_error($return);
   		}
        if( !is_user_logged_in() )
        {
            $return = array('message' => esc_html__('You must be logged in to submit a listings.', 'maxwheels-framework'));
      		wp_send_json_error($return);
        }
		else
		{

            if(isset($params['listing_id']) && $params['listing_id'] !="")
            {
                $mw_id = $params['listing_id'];
                $desc = isset( $_POST[ 'desc' ] ) ? wp_kses_post( $_POST[ 'desc' ] ) : '';
                $gallery = isset( $params[ 'selected_imgz_idz' ] ) ? sanitize_text_field( $params[ 'selected_imgz_idz' ] ) : '';
                $features = isset( $params[ 'mw-amens' ] ) ? ( $params[ 'mw-amens' ] ) : '';
                $address = isset( $params[ 'street-address' ] ) ? sanitize_text_field( $params[ 'street-address' ] ) : '';
                $latt = isset( $params[ 'mw-latt' ] ) ? sanitize_text_field( $params[ 'mw-latt' ] ) : '';
			    $long = isset( $params[ 'mw-long' ] ) ? sanitize_text_field( $params[ 'mw-long' ] ) : '';
                $location = isset( $params[ 'locations' ] ) ? sanitize_text_field( $params[ 'locations' ] ) : '';
                $approval = 'draft';
				if(maxwheels_framework_get_options('mw_badwords') !='')
				{
					$words		  =	explode( ',', maxwheels_framework_get_options('mw_badwords') );
					$replace	  =	maxwheels_framework_get_options('mw_badwords_replace');
					$final_desc  =	maxwheels_framework_badwords_filter( $words, $desc, $replace );
				}
				else
				{
					$final_desc  =	$desc;
				}
                update_post_meta($mw_id, 'mw_status_complete', '1');
                if(!empty($params['listing_id']) && $params['is_edit'] && $params['is_edit'] == 'yes')
                {
                    $approval = maxwheels_framework_get_listing_status($mw_id,true);
                }else{

                    $approval = maxwheels_framework_get_listing_status($mw_id);
                }
                $my_post = array(
                  'ID'            => $mw_id,
                  'post_content'  => $final_desc,
                  'post_status'   => $approval,
                  'post_type' 	  => 'mx-listings'
                );

                wp_update_post( $my_post );
                update_post_meta($mw_id, 'mw_status', '1');

                //gallery
				update_post_meta( $mw_id, 'mw_gallery', $gallery);
                //mark first image as featured
                $final_id = $first_value = $images_ids = '';
                if(get_post_meta($mw_id, 'mw_gallery', true) !="")
                {
                    $images_ids  = get_post_meta($mw_id, 'mw_gallery', true);
                    $first_value = explode(',', $images_ids);
                    $final_id   = array_shift($first_value);
                    set_post_thumbnail($mw_id, $final_id);
                }
//                echo $features."this is features";
//                exit();
                //features
               wp_set_object_terms( $mw_id, $features, 'mw-features' );
                //maps & lat long
				update_post_meta($mw_id, 'mw_street_addr', $address);
				update_post_meta($mw_id, 'mw_latt', $latt);
				update_post_meta($mw_id, 'mw_long', $long);
                //location
				wp_set_object_terms($mw_id, maxwheels_framework_get_ancestors($location,'mw-location'), 'mw-location');
				update_post_meta($mw_id, 'mw_loc', $location);
                // remove from session
                if (!session_id())
                {
                    session_start();
                    unset($_SESSION['listing-id']);
                }

                if(!empty($mw_id)  && isset($params['is_edit']) && $params['is_edit'] == 'yes')
                {
                    $success_msg =  esc_html__( 'Ad Updated Successfully.', 'propertya-framework' );
                    $link =  get_the_permalink($mw_id);
                    $return = array('message' =>$success_msg ,'referral' => $link);
                    wp_send_json_success($return);
                }
                else
                {
                    if($approval=='publish'){
                        $success_msg =  esc_html__( 'Listing Publish Successfully.', 'propertya-framework' );
                        $link =  get_the_permalink($mw_id);
                        $return = array('message' =>$success_msg ,'referral' => $link);
                        wp_send_json_success($return);

                    }else{
                        //listing_package_status($author_id,$mw_id);
                        $success_msg =  esc_html__( 'Publish your Listing on your Dashboard.', 'propertya-framework' );
                        $page_redirection = maxwheels_framework_get_link('page-dashboard.php');
                        $return = array('message' =>$success_msg ,'referral' => $page_redirection);
                        wp_send_json_success($return);

                    }

                }
            }
            else
            {
                $return = array('message' => esc_html__( 'There was an error while processing your request. Please, reload the page and try again.', 'maxwheels-framework' ));
                wp_send_json_error($return);	
            }
  		}
	}
}


add_action( 'wp_ajax_mw_mark_feature', 'maxwheels_framework_mw_feature' );
add_action( 'wp_ajax_nopriv_mw_mark_feature', 'maxwheels_framework_mw_feature' );
if (!function_exists ( 'maxwheels_framework_mw_feature' ))
{
    function maxwheels_framework_mw_feature()
    {
        $params = array();

        $list_id = $_POST['listings_ids'];
        parse_str($_POST['collect_data'], $params);
        if(maxwheels_framework_get_options('mw_demo') == 1 && !is_super_admin( get_current_user_id()))
        {
            $return = array('message' => esc_html__( 'Disable for Demo.', 'maxwheels-framework' ));
            wp_send_json_error($return);
        }
        if(!wp_verify_nonce($_POST['security'], 'check-security'))
        {
            $return = array('message' => esc_html__('Invalid security token sent.', 'maxwheels-framework'));
            wp_send_json_error($return);
        }
        if( !is_user_logged_in() )
        {
            $return = array('message' => esc_html__('You must be logged in to submit a listings.', 'maxwheels-framework'));
            wp_send_json_error($return);
        }
        else
        {
            if(isset($list_id) && $list_id !="")
            {
               $checkr= get_post_meta($list_id, 'mw_is_feature_listing', true);


                $expiry_days = $featured_listings = '';
                if(get_user_meta(get_current_user_id(), 'mw_pack_featuredlistings', true) !="" && get_post_meta($list_id, 'mw_is_feature_listing', true) =="0")
                {
                    $featured_listings = get_user_meta(get_current_user_id(), 'mw_pack_featuredlistings', true);
                    $expiry_days = get_user_meta(get_current_user_id(), 'mw_pack_exp_featured_for', true);
                    if($featured_listings > 0)
                    {
                        if(isset($expiry_days) && $expiry_days !="" && $expiry_days !="0" && $expiry_days == '-1')
                        {
                            update_post_meta($list_id, 'mw_feature_listing_for', $expiry_days);
                        }
                        else
                        {
                            $now = date('Y-m-d');
                            $date	=	date_create($now);
                            date_add($date,date_interval_create_from_date_string("$expiry_days days"));
                            $featured_listing_exp_date	=	 date_format($date,"Y-m-d");
                            update_post_meta($list_id, 'mw_feature_listing_for', $featured_listing_exp_date);
                        }
                        update_post_meta($list_id, 'mw_is_feature_listing', 1);
                        update_post_meta($list_id, 'mw_feature_listing_date',date('Y-m-d'));
                        $featured_listings	=	$featured_listings - 1;
                        update_user_meta( get_current_user_id(), 'mw_pack_featuredlistings', $featured_listings );
                        $return = array('message' => esc_html__( 'Add Featured Successfully.', 'maxwheels-framework' ),'page_link' => esc_url( get_the_permalink($list_id)));
                        wp_send_json_success($return);
                    }
                    else
                    {
                        update_post_meta($list_id, 'mw_is_feature_listing', 0);
                    }
                }
            }
            else
            {
                $return = array('message' => esc_html__( 'There was an error while processing your request. Please, reload the page and try again.', 'maxwheels-framework' ));
                wp_send_json_error($return);
            }
        }
    }
}


// Set Cover Image
add_action( 'wp_ajax_mw_gallery_images', 'maxwheels_framework_my_gallery' );
if (!function_exists ( 'maxwheels_framework_my_gallery' ))
{
	function maxwheels_framework_my_gallery()
	{
		if(maxwheels_framework_get_options('mw_demo') == 1 && !is_super_admin(get_current_user_id()))
		{
			$return = array('message' => esc_html__( 'Disable for Demo.', 'maxwheels-framework' ));
			wp_send_json_error($return);
		}
		else
		{
			if (!empty($_FILES)) {
			$mw_id = $_POST['listing_id'];	
			$galleryz = $list_creatz = array();
            $has_gallery = false;
            $mediaz = '';

            require_once ABSPATH . 'wp-admin/includes/image.php';
            require_once ABSPATH . 'wp-admin/includes/file.php';
            require_once ABSPATH . 'wp-admin/includes/media.php';
            $uploaded_file_size = $actual_size = $display_size = $size_arr = $allowed_file_types = $uploaded_file_type = '';
            $files = $_FILES["files"];
			$data = '';
            foreach ($files['name'] as $key => $value) {
                if ($files['name'][$key]) {
                    $file = array(
                        'name' => $files['name'][$key],
                        'type' => $files['type'][$key],
                        'tmp_name' => $files['tmp_name'][$key],
                        'error' => $files['error'][$key],
                        'size' => $files['size'][$key]
                    );
                    $uploaded_file_type = $files['type'][$key];
                    $uploaded_file_size = $files['size'][$key];
                    $allowed_file_types = array('image/jpg', 'image/jpeg', 'image/png');
                    if (!in_array($uploaded_file_type, $allowed_file_types))
					{
						$return = array('message' => esc_html__( 'Sorry, only JPG, JPEG, and PNG files are allowed.', 'maxwheels-framework' ));
						wp_send_json_error($return);
                    }
                    // Check max image limit
                    $media = '';
                    $media = get_attached_media('image', $mw_id);
                    $list_creatz = array();
                 
                    $_FILES = array("files" => $file);
                    foreach ($_FILES as $file => $array) {
                        $attachment_id = media_handle_upload('files', $mw_id);
                        if (is_wp_error($attachment_id)) {
							$return = array('message' => esc_html__( 'Sorry, this file type is not permitted for security reason.', 'maxwheels-framework' ));
						wp_send_json_error($return);
							
                        } 
                        else 
                        {
                            if (get_post_meta($mw_id, 'mw_gallery', true) != "") {
                                $imgaes = '';
                                $imgaes = get_post_meta($mw_id, 'mw_gallery', true);
                                $imgaes = $imgaes . ',' . $attachment_id;
                                update_post_meta($mw_id, 'mw_gallery', $imgaes);
                            } 
                            else
                            {
                                update_post_meta($mw_id, 'mw_gallery', $attachment_id);
                            }
                        }
                    }
                }
            }
				$all_idz = '';
				$all_idz = maxwheels_framework_fetch_gallery_idz($mw_id);
				 if(is_array($all_idz) && count($all_idz) > 0)
				 {
					$data .= '<ul class="custom-meta-gallery">';
					foreach($all_idz as $images_ids)
            		{
						$img_id	=	'';
						if (isset( $images_ids->ID))
						{
							$img_id	= 	$images_ids->ID;
						}
						else
						{
							$img_id	=	$images_ids;
						}
						 $thumb_imgs  = wp_get_attachment_image_src($img_id, 'maxwheels-user-thumb');
						 $data .= '<li class="sort_list_img" id="'.$img_id.'"><div class="custom-meta-gallery_container"><span class="img_suff"><i class="fas fa-arrows-alt shuffle-img"></i></span><span class="custom-gallery-del">
				 	<img id="'.$img_id.'" src="'.esc_url($thumb_imgs[0]).'" alt=""></span></div></li>';
					}
					$data .= '</ul>';
					$selected_attachments = '';
				    $selected_attachments = get_post_meta( $mw_id, 'mw_gallery', true );
					$return = array('referral_data' => $data, 'selected_attachments' => $selected_attachments);
					wp_send_json_success($return);
				 }
			}
		}
	}
}


// Delete Selected Gallery Images
add_action( 'wp_ajax_mw_delete_selected_gallery_attachment', 'maxwheels_framework_del_mygallery_attachments' );
if (!function_exists ( 'maxwheels_framework_del_mygallery_attachments' ))
{
	function maxwheels_framework_del_mygallery_attachments()
	{
		if(maxwheels_framework_get_options('mw_demo') == 1 && !is_super_admin(get_current_user_id()))
		{
			$return = array('message' => esc_html__( 'Disable for Demo.', 'maxwheels-framework' ));
			wp_send_json_error($return);
		}
		else
		{
			$attachment_id = $_POST['attachment_id'];
			$mw_id = $_POST['listing_id'];
			if(!empty($attachment_id) && !empty($mw_id))
			{
				wp_delete_attachment($attachment_id, true);
				if (get_post_meta($mw_id, 'mw_gallery', true) != "") {
					$ids = get_post_meta($mw_id, 'mw_gallery', true);
					$res = str_replace($attachment_id, "", $ids);
					$res = str_replace(',,', ",", $res);
					$img_ids = trim($res, ',');
					update_post_meta($mw_id, 'mw_gallery', $img_ids);
				}
				$selected_attachments = '';
				$selected_attachments = get_post_meta($mw_id, 'mw_gallery', true);
				$return = array('selected_attachments' => $selected_attachments);
				wp_send_json_success($return);	
			}
		}
	}
}