<?php
/**
 * The Template for displaying all single products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     1.6.4
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

get_header( 'shop' ); ?>

	<?php
		/**
		 * woocommerce_before_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
		 * @hooked woocommerce_breadcrumb - 20
		 */
		do_action( 'woocommerce_before_main_content' );
		$shop_page_url = esc_url(get_permalink( wc_get_page_id( 'shop' ) ));
		$column_size = 'col-xxl-9 col-xl-9 col-lg-12 col-md-12 col-12';
		if (!is_active_sidebar( 'mw_shop_detialsidebar' ) )
		{
			$column_size = 'col-xxl-12 col-xl-12 col-lg-12 col-md-12 col-12';
		}
	?>
		<div class="mw-breads white-bg">
			<div class="container">
				<div class="row">
					<div class="col-xxl-12 col-lg-12 col-md-12 col-sm-12 col-12">
						<ol class="breadcrumb">
						  <li class="breadcrumb-item"><a href="<?php echo esc_url(home_url( '/' )); ?>"><i class="fas fa-home"></i>  <?php echo esc_html__('Home','maxwheels'); ?></a></li>
						  <li class="breadcrumb-item"><a href="<?php echo esc_url($shop_page_url); ?>"><?php echo esc_html__('Back to shop','maxwheels'); ?></a></li>
						  <?php
							if ( ( get_post_type() == 'product' ) && is_singular() )
							{
								global $post;
								$taxonomy = 'product_cat';
								$terms = get_the_terms( $post->ID, $taxonomy );
								if ( $terms && ! is_wp_error( $terms ) )
								{
									foreach ( $terms as $c )
									{
							?>
									<li class="breadcrumb-item" aria-current="page"><a href="<?php echo esc_url(get_term_link($c->term_id, $c->taxonomy)); ?>"><?php echo esc_html($c->name); ?></a></li>
							<?php
									}
								}
							}
							?>
						  <li class="breadcrumb-item active" aria-current="page"><?php echo esc_html(get_the_title($post->ID)); ?></li>
						</ol>
					</div>	
				</div>
			</div>	
		</div>
		<section class="custom-padding light-bg mw-shop mw-shop-detial">
			<div class="container">
				<div class="row">
					<div class="<?php echo esc_attr($column_size); ?>">
					 <?php while ( have_posts() ) : ?>
						<?php the_post(); ?>
						<?php wc_get_template_part( 'content', 'single-product' ); ?>
					 <?php endwhile; // end of the loop. ?>
					</div>
					<?php if ( is_active_sidebar( 'mw_shop_detialsidebar' ) ) { ?>
					<div class="col-xl-3 col-xxl-3 col-md-12 col-xs-12 col-sm-12 col-12">
							<aside class="shop-sidebar mt-top position-sticky">
							<?php dynamic_sidebar( 'mw_shop_detialsidebar' ); ?>  
							</aside>	
					</div>
					<?php } ?>
				</div>
			</div>
		</section>	
	<?php
		/**
		 * woocommerce_after_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
		 */
		do_action( 'woocommerce_after_main_content' );
	?>
<?php
get_footer( 'shop' );