<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.4.0
 */
defined( 'ABSPATH' ) || exit;
get_header( 'shop' );

/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
do_action( 'woocommerce_before_main_content' );
$column_size = 'col-xxl-9 col-xl-9 col-lg-12 col-md-12 col-12';
if (!is_active_sidebar( 'mw_shop_sidebar' ) )
{
	$column_size = 'col-xxl-12 col-xl-12 col-lg-12 col-md-12 col-12';
}
?>
<div class="mw-breads white-bg">
	<div class="container">
		<div class="row">
			<div class="col-xxl-12 col-lg-12 col-md-12 col-sm-12 col-12">
				<ol class="breadcrumb">
				  <li class="breadcrumb-item"><a href="<?php echo esc_url(home_url( '/' )); ?>"><i class="fas fa-home"></i>  <?php echo esc_html__('Home','maxwheels'); ?></a></li>
				  <li class="breadcrumb-item active" aria-current="page"><?php echo esc_html__('Shop','maxwheels'); ?></li>
				</ol>
			</div>	
		</div>
	</div>	
</div>
<section class="custom-padding light-bg mw-shop">
    <div class="container">
        <div class="row">
        <div class="<?php echo esc_attr($column_size); ?>">
		<?php 
		global $maxwheels_options;
		if(maxwheels_strings('show_banners_on_product') == 1)
		{ 
		?>
				<?php if (isset($maxwheels_options['opt-slides-do']) && !empty($maxwheels_options['opt-slides-do'])){ ?>
					<div class="shop-banner-slider owl-carousel owl-theme">
					<?php 
						foreach($maxwheels_options['opt-slides-do'] as $get_data){?>
						<div class="item">
							<a href="<?php echo esc_url($get_data['url']); ?>"><img class="img-fluid" alt="<?php echo esc_attr('image not found','dwt-listing'); ?>" src="<?php echo esc_url($get_data['image']); ?>"></a>
						</div>
						<?php } ?>
					</div> 
				<?php } ?>    
			<div class="clearfix"></div>
		<?php
		}
		?>
<?php
if ( woocommerce_product_loop() ) {

	/**
	 * Hook: woocommerce_before_shop_loop.
	 *
	 * @hooked woocommerce_output_all_notices - 10
	 * @hooked woocommerce_result_count - 20
	 * @hooked woocommerce_catalog_ordering - 30
	 */
	wc_get_loop_prop( 'per_page' );
	?>
			<div class="filter-sorting-bar d-flex flex-wrap justify-content-between align-items-center">
            <h4><?php echo wp_sprintf(__('<span class="clr-yal"> %d </span> Results Found ', 'maxwheels'),esc_attr(wc_get_loop_prop( 'total' ))); ?></h4>
				<div class=" d-flex d-block">
				  <div class="short-by">
					<?php woocommerce_catalog_ordering(); ?>
				  </div>
				</div>
			</div>
	<?php		
	woocommerce_product_loop_start();
	if ( wc_get_loop_prop( 'total' ) ) {
		while ( have_posts() ) {
			the_post();
			do_action( 'woocommerce_shop_loop' );
			wc_get_template_part( 'content', 'product' );
		}
	}
	woocommerce_product_loop_end();
	/**
	 * Hook: woocommerce_after_shop_loop.
	 *
	 * @hooked woocommerce_pagination - 10
	 */
	maxwheels_pagination();
	do_action( 'woocommerce_after_shop_loop' );
} else {
	/**
	 * Hook: woocommerce_no_products_found.
	 *
	 * @hooked wc_no_products_found - 10
	 */
	do_action( 'woocommerce_no_products_found' );
}
?>
            </div>
			<?php echo get_sidebar('shop'); ?>	
            </div>
        </div>
</section>    
<?php
    

/**
 * Hook: woocommerce_after_main_content.
 *
 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
 */
do_action( 'woocommerce_after_main_content' );

get_footer( 'shop' );